@@ -36,7 +36,7 @@ impl EnterpriseAdmin {
             crate::progenitor_support::encode_path(&enterprise.to_string()),
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -115,7 +115,7 @@ impl EnterpriseAdmin {
             query
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -235,7 +235,7 @@ impl EnterpriseAdmin {
             crate::progenitor_support::encode_path(&enterprise.to_string()),
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -253,22 +253,13 @@ impl EnterpriseAdmin {
      *
      * * `enterprise: &str` -- The slug version of the enterprise name. You can also substitute this value with the enterprise id.
      */
-    pub async fn set_allowed_actions_enterprise(
-        &self,
-        enterprise: &str,
-        body: &crate::types::SelectedActions,
-    ) -> Result<()> {
+    pub async fn set_allowed_actions_enterprise(&self, enterprise: &str) -> Result<()> {
         let url = format!(
             "/enterprises/{}/actions/permissions/selected-actions",
             crate::progenitor_support::encode_path(&enterprise.to_string()),
         );
 
-        self.client
-            .put(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
-            .await
+        self.client.put(&url, None).await
     }
 
     /**
@@ -314,7 +305,7 @@ impl EnterpriseAdmin {
             query
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -377,7 +368,7 @@ impl EnterpriseAdmin {
             crate::progenitor_support::encode_path(&runner_group_id.to_string()),
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -492,7 +483,7 @@ impl EnterpriseAdmin {
             query
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -643,7 +634,7 @@ impl EnterpriseAdmin {
             query
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -792,7 +783,7 @@ impl EnterpriseAdmin {
             query
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -819,7 +810,7 @@ impl EnterpriseAdmin {
             crate::progenitor_support::encode_path(&enterprise.to_string()),
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -844,7 +835,7 @@ impl EnterpriseAdmin {
             crate::progenitor_support::encode_path(&enterprise.to_string()),
         );
 
-        self.client.get_all_pages(&url).await
+        self.client.get_all_pages(&url, None).await
     }
 
     /**
@@ -945,7 +936,7 @@ impl EnterpriseAdmin {
             crate::progenitor_support::encode_path(&runner_id.to_string()),
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -1048,7 +1039,7 @@ impl EnterpriseAdmin {
             query
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -1096,7 +1087,7 @@ impl EnterpriseAdmin {
             query
         );
 
-        self.client.get_all_pages(&url).await
+        self.client.get_all_pages(&url, None).await
     }
 
     /**
@@ -1150,7 +1141,7 @@ impl EnterpriseAdmin {
             query
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -1225,7 +1216,7 @@ impl EnterpriseAdmin {
             query
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -1391,7 +1382,7 @@ impl EnterpriseAdmin {
             query
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -1454,7 +1445,7 @@ impl EnterpriseAdmin {
             crate::progenitor_support::encode_path(&scim_user_id.to_string()),
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
