@@ -36,7 +36,7 @@ impl Issues {
      *  \\* `created`: Issues created by you  
      *  \\* `mentioned`: Issues mentioning you  
      *  \\* `subscribed`: Issues you're subscribed to updates for  
-     *  \\* `all`: All issues the authenticated user can see, regardless of participation or creation.
+     *  \\* `all` or `repos`: All issues the authenticated user can see, regardless of participation or creation.
      * * `state: crate::types::IssuesListState` -- Indicates the state of the issues to return. Can be either `open`, `closed`, or `all`.
      * * `labels: &str` -- A list of comma separated label names. Example: `bug,ui,@high`.
      * * `sort: crate::types::IssuesListSort` -- What to sort results by. Can be either `created`, `updated`, `comments`.
@@ -102,7 +102,7 @@ impl Issues {
         }
         let url = format!("/issues?{}", query);
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -169,7 +169,7 @@ impl Issues {
         }
         let url = format!("/issues?{}", query);
 
-        self.client.get_all_pages(&url).await
+        self.client.get_all_pages(&url, None).await
     }
 
     /**
@@ -194,7 +194,7 @@ impl Issues {
      *  \\* `created`: Issues created by you  
      *  \\* `mentioned`: Issues mentioning you  
      *  \\* `subscribed`: Issues you're subscribed to updates for  
-     *  \\* `all`: All issues the authenticated user can see, regardless of participation or creation.
+     *  \\* `all` or `repos`: All issues the authenticated user can see, regardless of participation or creation.
      * * `state: crate::types::IssuesListState` -- Indicates the state of the issues to return. Can be either `open`, `closed`, or `all`.
      * * `labels: &str` -- A list of comma separated label names. Example: `bug,ui,@high`.
      * * `sort: crate::types::IssuesListSort` -- What to sort results by. Can be either `created`, `updated`, `comments`.
@@ -245,7 +245,7 @@ impl Issues {
             query
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -298,7 +298,7 @@ impl Issues {
             query
         );
 
-        self.client.get_all_pages(&url).await
+        self.client.get_all_pages(&url, None).await
     }
 
     /**
@@ -345,7 +345,7 @@ impl Issues {
             query
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -370,7 +370,7 @@ impl Issues {
             crate::progenitor_support::encode_path(&repo.to_string()),
         );
 
-        self.client.get_all_pages(&url).await
+        self.client.get_all_pages(&url, None).await
     }
 
     /**
@@ -405,7 +405,7 @@ impl Issues {
             crate::progenitor_support::encode_path(&assignee.to_string()),
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -496,7 +496,7 @@ impl Issues {
             query
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -565,7 +565,7 @@ impl Issues {
             query
         );
 
-        self.client.get_all_pages(&url).await
+        self.client.get_all_pages(&url, None).await
     }
 
     /**
@@ -575,7 +575,7 @@ impl Issues {
      *
      * Any user with pull access to a repository can create an issue. If [issues are disabled in the repository](https://help.github.com/articles/disabling-issues/), the API returns a `410 Gone` status.
      *
-     * This endpoint triggers [notifications](https://docs.github.com/en/github/managing-subscriptions-and-notifications-on-github/about-notifications). Creating content too quickly using this endpoint may result in abuse rate limiting. See "[Abuse rate limits](https://docs.github.com/rest/overview/resources-in-the-rest-api#abuse-rate-limits)" and "[Dealing with abuse rate limits](https://docs.github.com/rest/guides/best-practices-for-integrators#dealing-with-abuse-rate-limits)" for details.
+     * This endpoint triggers [notifications](https://docs.github.com/en/github/managing-subscriptions-and-notifications-on-github/about-notifications). Creating content too quickly using this endpoint may result in secondary rate limiting. See "[Secondary rate limits](https://docs.github.com/rest/overview/resources-in-the-rest-api#secondary-rate-limits)" and "[Dealing with secondary rate limits](https://docs.github.com/rest/guides/best-practices-for-integrators#dealing-with-secondary-rate-limits)" for details.
      *
      * FROM: <https://docs.github.com/rest/reference/issues#create-an-issue>
      *
@@ -659,7 +659,7 @@ impl Issues {
             query
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -701,7 +701,7 @@ impl Issues {
             query
         );
 
-        self.client.get_all_pages(&url).await
+        self.client.get_all_pages(&url, None).await
     }
 
     /**
@@ -732,7 +732,7 @@ impl Issues {
             crate::progenitor_support::encode_path(&comment_id.to_string()),
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -842,7 +842,7 @@ impl Issues {
             query
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -867,7 +867,7 @@ impl Issues {
             crate::progenitor_support::encode_path(&repo.to_string()),
         );
 
-        self.client.get_all_pages(&url).await
+        self.client.get_all_pages(&url, None).await
     }
 
     /**
@@ -898,7 +898,7 @@ impl Issues {
             crate::progenitor_support::encode_path(&event_id.to_string()),
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -939,7 +939,7 @@ impl Issues {
             crate::progenitor_support::encode_path(&issue_number.to_string()),
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -1105,7 +1105,7 @@ impl Issues {
             query
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -1145,7 +1145,7 @@ impl Issues {
             query
         );
 
-        self.client.get_all_pages(&url).await
+        self.client.get_all_pages(&url, None).await
     }
 
     /**
@@ -1153,7 +1153,7 @@ impl Issues {
      *
      * This function performs a `POST` to the `/repos/{owner}/{repo}/issues/{issue_number}/comments` endpoint.
      *
-     * This endpoint triggers [notifications](https://docs.github.com/en/github/managing-subscriptions-and-notifications-on-github/about-notifications). Creating content too quickly using this endpoint may result in abuse rate limiting. See "[Abuse rate limits](https://docs.github.com/rest/overview/resources-in-the-rest-api#abuse-rate-limits)" and "[Dealing with abuse rate limits](https://docs.github.com/rest/guides/best-practices-for-integrators#dealing-with-abuse-rate-limits)" for details.
+     * This endpoint triggers [notifications](https://docs.github.com/en/github/managing-subscriptions-and-notifications-on-github/about-notifications). Creating content too quickly using this endpoint may result in secondary rate limiting. See "[Secondary rate limits](https://docs.github.com/rest/overview/resources-in-the-rest-api#secondary-rate-limits)" and "[Dealing with secondary rate limits](https://docs.github.com/rest/guides/best-practices-for-integrators#dealing-with-secondary-rate-limits)" for details.
      *
      * FROM: <https://docs.github.com/rest/reference/issues#create-an-issue-comment>
      *
@@ -1232,7 +1232,7 @@ impl Issues {
             query
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -1259,7 +1259,7 @@ impl Issues {
             crate::progenitor_support::encode_path(&issue_number.to_string()),
         );
 
-        self.client.get_all_pages(&url).await
+        self.client.get_all_pages(&url, None).await
     }
 
     /**
@@ -1309,7 +1309,7 @@ impl Issues {
             query
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -1336,7 +1336,7 @@ impl Issues {
             crate::progenitor_support::encode_path(&issue_number.to_string()),
         );
 
-        self.client.get_all_pages(&url).await
+        self.client.get_all_pages(&url, None).await
     }
 
     /**
@@ -1396,7 +1396,6 @@ impl Issues {
         owner: &str,
         repo: &str,
         issue_number: i64,
-        body: &crate::types::IssuesAddLabelsRequestOneOf,
     ) -> Result<Vec<crate::types::Label>> {
         let url = format!(
             "/repos/{}/{}/issues/{}/labels",
@@ -1405,12 +1404,7 @@ impl Issues {
             crate::progenitor_support::encode_path(&issue_number.to_string()),
         );
 
-        self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
-            .await
+        self.client.post(&url, None).await
     }
 
     /**
@@ -1567,7 +1561,7 @@ impl Issues {
         issue_number: i64,
         per_page: i64,
         page: i64,
-    ) -> Result<Vec<crate::types::TimelineIssueEvents>> {
+    ) -> Result<Vec<crate::types::TimelineEvent>> {
         let mut query = String::new();
         let mut query_args: Vec<String> = Default::default();
         if page > 0 {
@@ -1590,7 +1584,7 @@ impl Issues {
             query
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -1609,7 +1603,7 @@ impl Issues {
         owner: &str,
         repo: &str,
         issue_number: i64,
-    ) -> Result<Vec<crate::types::TimelineIssueEvents>> {
+    ) -> Result<Vec<crate::types::TimelineEvent>> {
         let url = format!(
             "/repos/{}/{}/issues/{}/timeline",
             crate::progenitor_support::encode_path(&owner.to_string()),
@@ -1617,7 +1611,7 @@ impl Issues {
             crate::progenitor_support::encode_path(&issue_number.to_string()),
         );
 
-        self.client.get_all_pages(&url).await
+        self.client.get_all_pages(&url, None).await
     }
 
     /**
@@ -1664,7 +1658,7 @@ impl Issues {
             query
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -1689,7 +1683,7 @@ impl Issues {
             crate::progenitor_support::encode_path(&repo.to_string()),
         );
 
-        self.client.get_all_pages(&url).await
+        self.client.get_all_pages(&url, None).await
     }
 
     /**
@@ -1754,7 +1748,7 @@ impl Issues {
             crate::progenitor_support::encode_path(&name.to_string()),
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -1873,7 +1867,7 @@ impl Issues {
             query
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -1913,7 +1907,7 @@ impl Issues {
             query
         );
 
-        self.client.get_all_pages(&url).await
+        self.client.get_all_pages(&url, None).await
     }
 
     /**
@@ -1978,7 +1972,7 @@ impl Issues {
             crate::progenitor_support::encode_path(&milestone_number.to_string()),
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -2096,7 +2090,7 @@ impl Issues {
             query
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -2123,7 +2117,7 @@ impl Issues {
             crate::progenitor_support::encode_path(&milestone_number.to_string()),
         );
 
-        self.client.get_all_pages(&url).await
+        self.client.get_all_pages(&url, None).await
     }
 
     /**
@@ -2147,7 +2141,7 @@ impl Issues {
      *  \\* `created`: Issues created by you  
      *  \\* `mentioned`: Issues mentioning you  
      *  \\* `subscribed`: Issues you're subscribed to updates for  
-     *  \\* `all`: All issues the authenticated user can see, regardless of participation or creation.
+     *  \\* `all` or `repos`: All issues the authenticated user can see, regardless of participation or creation.
      * * `state: crate::types::IssuesListState` -- Indicates the state of the issues to return. Can be either `open`, `closed`, or `all`.
      * * `labels: &str` -- A list of comma separated label names. Example: `bug,ui,@high`.
      * * `sort: crate::types::IssuesListSort` -- What to sort results by. Can be either `created`, `updated`, `comments`.
@@ -2193,7 +2187,7 @@ impl Issues {
         }
         let url = format!("/user/issues?{}", query);
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -2241,6 +2235,6 @@ impl Issues {
         }
         let url = format!("/user/issues?{}", query);
 
-        self.client.get_all_pages(&url).await
+        self.client.get_all_pages(&url, None).await
     }
 }
