@@ -49,7 +49,7 @@ impl Orgs {
         }
         let url = format!("/organizations?{}", query);
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -79,7 +79,7 @@ impl Orgs {
         }
         let url = format!("/organizations?{}", query);
 
-        self.client.get_all_pages(&url).await
+        self.client.get_all_pages(&url, None).await
     }
 
     /**
@@ -103,7 +103,7 @@ impl Orgs {
             crate::progenitor_support::encode_path(&org.to_string()),
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -211,7 +211,7 @@ impl Orgs {
             query
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -261,7 +261,7 @@ impl Orgs {
             query
         );
 
-        self.client.get_all_pages(&url).await
+        self.client.get_all_pages(&url, None).await
     }
 
     /**
@@ -283,7 +283,7 @@ impl Orgs {
             crate::progenitor_support::encode_path(&org.to_string()),
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -303,7 +303,7 @@ impl Orgs {
             crate::progenitor_support::encode_path(&org.to_string()),
         );
 
-        self.client.get_all_pages(&url).await
+        self.client.get_all_pages(&url, None).await
     }
 
     /**
@@ -327,7 +327,7 @@ impl Orgs {
             crate::progenitor_support::encode_path(&username.to_string()),
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -402,7 +402,7 @@ impl Orgs {
             crate::progenitor_support::encode_path(&org.to_string()),
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -427,7 +427,7 @@ impl Orgs {
             crate::progenitor_support::encode_path(&org.to_string()),
         );
 
-        self.client.get_all_pages(&url).await
+        self.client.get_all_pages(&url, None).await
     }
 
     /**
@@ -497,7 +497,7 @@ impl Orgs {
             query
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -520,7 +520,7 @@ impl Orgs {
             crate::progenitor_support::encode_path(&org.to_string()),
         );
 
-        self.client.get_all_pages(&url).await
+        self.client.get_all_pages(&url, None).await
     }
 
     /**
@@ -564,7 +564,7 @@ impl Orgs {
             query
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -584,7 +584,7 @@ impl Orgs {
             crate::progenitor_support::encode_path(&org.to_string()),
         );
 
-        self.client.get_all_pages(&url).await
+        self.client.get_all_pages(&url, None).await
     }
 
     /**
@@ -639,7 +639,7 @@ impl Orgs {
             crate::progenitor_support::encode_path(&hook_id.to_string()),
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -727,7 +727,7 @@ impl Orgs {
             crate::progenitor_support::encode_path(&hook_id.to_string()),
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -766,6 +766,153 @@ impl Orgs {
             .await
     }
 
+    /**
+     * List deliveries for an organization webhook.
+     *
+     * This function performs a `GET` to the `/orgs/{org}/hooks/{hook_id}/deliveries` endpoint.
+     *
+     * Returns a list of webhook deliveries for a webhook configured in an organization.
+     *
+     * FROM: <https://docs.github.com/rest/reference/orgs#list-deliveries-for-an-organization-webhook>
+     *
+     * **Parameters:**
+     *
+     * * `org: &str`
+     * * `hook_id: i64`
+     * * `per_page: i64` -- Results per page (max 100).
+     * * `cursor: &str` -- Used for pagination: the starting delivery from which the page of deliveries is fetched. Refer to the `link` header for the next and previous page cursors.
+     */
+    pub async fn list_webhook_deliveries(
+        &self,
+        org: &str,
+        hook_id: i64,
+        per_page: i64,
+        cursor: &str,
+    ) -> Result<Vec<crate::types::HookDeliveryItem>> {
+        let mut query = String::new();
+        let mut query_args: Vec<String> = Default::default();
+        if !cursor.is_empty() {
+            query_args.push(format!("cursor={}", cursor));
+        }
+        if per_page > 0 {
+            query_args.push(format!("per_page={}", per_page));
+        }
+        for (i, n) in query_args.iter().enumerate() {
+            if i > 0 {
+                query.push('&');
+            }
+            query.push_str(n);
+        }
+        let url = format!(
+            "/orgs/{}/hooks/{}/deliveries?{}",
+            crate::progenitor_support::encode_path(&org.to_string()),
+            crate::progenitor_support::encode_path(&hook_id.to_string()),
+            query
+        );
+
+        self.client.get(&url, None).await
+    }
+
+    /**
+     * List deliveries for an organization webhook.
+     *
+     * This function performs a `GET` to the `/orgs/{org}/hooks/{hook_id}/deliveries` endpoint.
+     *
+     * As opposed to `list_webhook_deliveries`, this function returns all the pages of the request at once.
+     *
+     * Returns a list of webhook deliveries for a webhook configured in an organization.
+     *
+     * FROM: <https://docs.github.com/rest/reference/orgs#list-deliveries-for-an-organization-webhook>
+     */
+    pub async fn list_all_webhook_deliveries(
+        &self,
+        org: &str,
+        hook_id: i64,
+        cursor: &str,
+    ) -> Result<Vec<crate::types::HookDeliveryItem>> {
+        let mut query = String::new();
+        let mut query_args: Vec<String> = Default::default();
+        if !cursor.is_empty() {
+            query_args.push(format!("cursor={}", cursor));
+        }
+        for (i, n) in query_args.iter().enumerate() {
+            if i > 0 {
+                query.push('&');
+            }
+            query.push_str(n);
+        }
+        let url = format!(
+            "/orgs/{}/hooks/{}/deliveries?{}",
+            crate::progenitor_support::encode_path(&org.to_string()),
+            crate::progenitor_support::encode_path(&hook_id.to_string()),
+            query
+        );
+
+        self.client.get_all_pages(&url, None).await
+    }
+
+    /**
+     * Get a webhook delivery for an organization webhook.
+     *
+     * This function performs a `GET` to the `/orgs/{org}/hooks/{hook_id}/deliveries/{delivery_id}` endpoint.
+     *
+     * Returns a delivery for a webhook configured in an organization.
+     *
+     * FROM: <https://docs.github.com/rest/reference/orgs#get-a-webhook-delivery-for-an-organization-webhook>
+     *
+     * **Parameters:**
+     *
+     * * `org: &str`
+     * * `hook_id: i64`
+     * * `delivery_id: i64`
+     */
+    pub async fn get_webhook_delivery(
+        &self,
+        org: &str,
+        hook_id: i64,
+        delivery_id: i64,
+    ) -> Result<crate::types::HookDelivery> {
+        let url = format!(
+            "/orgs/{}/hooks/{}/deliveries/{}",
+            crate::progenitor_support::encode_path(&org.to_string()),
+            crate::progenitor_support::encode_path(&hook_id.to_string()),
+            crate::progenitor_support::encode_path(&delivery_id.to_string()),
+        );
+
+        self.client.get(&url, None).await
+    }
+
+    /**
+     * Redeliver a delivery for an organization webhook.
+     *
+     * This function performs a `POST` to the `/orgs/{org}/hooks/{hook_id}/deliveries/{delivery_id}/attempts` endpoint.
+     *
+     * Redeliver a delivery for a webhook configured in an organization.
+     *
+     * FROM: <https://docs.github.com/rest/reference/orgs#redeliver-a-delivery-for-an-organization-webhook>
+     *
+     * **Parameters:**
+     *
+     * * `org: &str`
+     * * `hook_id: i64`
+     * * `delivery_id: i64`
+     */
+    pub async fn redeliver_webhook_delivery(
+        &self,
+        org: &str,
+        hook_id: i64,
+        delivery_id: i64,
+    ) -> Result<crate::types::Data> {
+        let url = format!(
+            "/orgs/{}/hooks/{}/deliveries/{}/attempts",
+            crate::progenitor_support::encode_path(&org.to_string()),
+            crate::progenitor_support::encode_path(&hook_id.to_string()),
+            crate::progenitor_support::encode_path(&delivery_id.to_string()),
+        );
+
+        self.client.post(&url, None).await
+    }
+
     /**
      * Ping an organization webhook.
      *
@@ -831,7 +978,7 @@ impl Orgs {
             query
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -875,7 +1022,7 @@ impl Orgs {
             query
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -898,7 +1045,7 @@ impl Orgs {
             crate::progenitor_support::encode_path(&org.to_string()),
         );
 
-        self.client.get_all_pages(&url).await
+        self.client.get_all_pages(&url, None).await
     }
 
     /**
@@ -908,7 +1055,7 @@ impl Orgs {
      *
      * Invite people to an organization by using their GitHub user ID or their email address. In order to create invitations in an organization, the authenticated user must be an organization owner.
      *
-     * This endpoint triggers [notifications](https://docs.github.com/en/github/managing-subscriptions-and-notifications-on-github/about-notifications). Creating content too quickly using this endpoint may result in abuse rate limiting. See "[Abuse rate limits](https://docs.github.com/rest/overview/resources-in-the-rest-api#abuse-rate-limits)" and "[Dealing with abuse rate limits](https://docs.github.com/rest/guides/best-practices-for-integrators#dealing-with-rate-limits)" for details.
+     * This endpoint triggers [notifications](https://docs.github.com/en/github/managing-subscriptions-and-notifications-on-github/about-notifications). Creating content too quickly using this endpoint may result in secondary rate limiting. See "[Secondary rate limits](https://docs.github.com/rest/overview/resources-in-the-rest-api#secondary-rate-limits)" and "[Dealing with secondary rate limits](https://docs.github.com/rest/guides/best-practices-for-integrators#dealing-with-secondary-rate-limits)" for details.
      *
      * FROM: <https://docs.github.com/rest/reference/orgs#create-an-organization-invitation>
      *
@@ -1004,7 +1151,7 @@ impl Orgs {
             query
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -1029,7 +1176,7 @@ impl Orgs {
             crate::progenitor_support::encode_path(&invitation_id.to_string()),
         );
 
-        self.client.get_all_pages(&url).await
+        self.client.get_all_pages(&url, None).await
     }
 
     /**
@@ -1084,7 +1231,7 @@ impl Orgs {
             query
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -1120,7 +1267,7 @@ impl Orgs {
             query
         );
 
-        self.client.get_all_pages(&url).await
+        self.client.get_all_pages(&url, None).await
     }
 
     /**
@@ -1144,7 +1291,7 @@ impl Orgs {
             crate::progenitor_support::encode_path(&username.to_string()),
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -1196,7 +1343,7 @@ impl Orgs {
             crate::progenitor_support::encode_path(&username.to_string()),
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -1313,7 +1460,7 @@ impl Orgs {
             query
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -1347,7 +1494,7 @@ impl Orgs {
             query
         );
 
-        self.client.get_all_pages(&url).await
+        self.client.get_all_pages(&url, None).await
     }
 
     /**
@@ -1443,7 +1590,7 @@ impl Orgs {
             query
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -1466,7 +1613,7 @@ impl Orgs {
             crate::progenitor_support::encode_path(&org.to_string()),
         );
 
-        self.client.get_all_pages(&url).await
+        self.client.get_all_pages(&url, None).await
     }
 
     /**
@@ -1490,7 +1637,7 @@ impl Orgs {
             crate::progenitor_support::encode_path(&username.to_string()),
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -1589,7 +1736,7 @@ impl Orgs {
         }
         let url = format!("/user/memberships/orgs?{}", query);
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -1618,7 +1765,7 @@ impl Orgs {
         }
         let url = format!("/user/memberships/orgs?{}", query);
 
-        self.client.get_all_pages(&url).await
+        self.client.get_all_pages(&url, None).await
     }
 
     /**
@@ -1643,7 +1790,7 @@ impl Orgs {
             crate::progenitor_support::encode_path(&org.to_string()),
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -1716,7 +1863,7 @@ impl Orgs {
         }
         let url = format!("/user/orgs?{}", query);
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -1738,7 +1885,7 @@ impl Orgs {
         &self,
     ) -> Result<Vec<crate::types::OrganizationSimple>> {
         let url = "/user/orgs".to_string();
-        self.client.get_all_pages(&url).await
+        self.client.get_all_pages(&url, None).await
     }
 
     /**
@@ -1784,7 +1931,7 @@ impl Orgs {
             query
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -1809,6 +1956,6 @@ impl Orgs {
             crate::progenitor_support::encode_path(&username.to_string()),
         );
 
-        self.client.get_all_pages(&url).await
+        self.client.get_all_pages(&url, None).await
     }
 }
