@@ -56,7 +56,7 @@ impl Projects {
             query
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -90,7 +90,7 @@ impl Projects {
             query
         );
 
-        self.client.get_all_pages(&url).await
+        self.client.get_all_pages(&url, None).await
     }
 
     /**
@@ -143,7 +143,7 @@ impl Projects {
             crate::progenitor_support::encode_path(&card_id.to_string()),
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -249,7 +249,7 @@ impl Projects {
             crate::progenitor_support::encode_path(&column_id.to_string()),
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -349,7 +349,7 @@ impl Projects {
             query
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -383,7 +383,7 @@ impl Projects {
             query
         );
 
-        self.client.get_all_pages(&url).await
+        self.client.get_all_pages(&url, None).await
     }
 
     /**
@@ -399,22 +399,13 @@ impl Projects {
      *
      * * `column_id: i64` -- column_id parameter.
      */
-    pub async fn create_card(
-        &self,
-        column_id: i64,
-        body: &crate::types::ProjectsCreateCardRequestOneOf,
-    ) -> Result<crate::types::ProjectCard> {
+    pub async fn create_card(&self, column_id: i64) -> Result<crate::types::ProjectCard> {
         let url = format!(
             "/projects/columns/{}/cards",
             crate::progenitor_support::encode_path(&column_id.to_string()),
         );
 
-        self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
-            .await
+        self.client.post(&url, None).await
     }
 
     /**
@@ -467,7 +458,7 @@ impl Projects {
             crate::progenitor_support::encode_path(&project_id.to_string()),
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -570,7 +561,7 @@ impl Projects {
             query
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -604,7 +595,7 @@ impl Projects {
             query
         );
 
-        self.client.get_all_pages(&url).await
+        self.client.get_all_pages(&url, None).await
     }
 
     /**
@@ -690,7 +681,7 @@ impl Projects {
             crate::progenitor_support::encode_path(&username.to_string()),
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -734,7 +725,7 @@ impl Projects {
             query
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -757,7 +748,7 @@ impl Projects {
             crate::progenitor_support::encode_path(&project_id.to_string()),
         );
 
-        self.client.get_all_pages(&url).await
+        self.client.get_all_pages(&url, None).await
     }
 
     /**
@@ -838,7 +829,7 @@ impl Projects {
             query
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -874,7 +865,7 @@ impl Projects {
             query
         );
 
-        self.client.get_all_pages(&url).await
+        self.client.get_all_pages(&url, None).await
     }
 
     /**
@@ -977,7 +968,7 @@ impl Projects {
             query
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -1011,6 +1002,6 @@ impl Projects {
             query
         );
 
-        self.client.get_all_pages(&url).await
+        self.client.get_all_pages(&url, None).await
     }
 }
